local MunMapdefaults =
{
    showMundusStones = true,
	showTamrielStones = true,
	showStoneType = {
		[1] = true,
		[2] = true,
		[3] = true,
		[4] = true,
		[5] = true,
		[6] = true,
		[7] = true,
		[8] = true,
		[9] = true,
		[10] = true,
		[11] = true,
		[12] = true,
		[13] = true,
	}
}

-- Gets Tool Tip Text
local function GetInfoFromTag(pin)
	local _, pinTag = pin:GetPinTypeAndTag()
	local mundusname = MunMap.localization["filter"..pinTag[3]]
	local mundustype = MunMap.localization["filtertooltip"..pinTag[3]]

	return mundusname, mundustype
end

-- Creates Tool Tip
MunMap.pinTooltipCreator = {
	creator = function(pin)
		local mundusname, mundustype = GetInfoFromTag(pin)
		InformationTooltip:AddLine("Mundus Stone Information:", "", ZO_HIGHLIGHT_TEXT:UnpackRGB())
		InformationTooltip:AddLine(mundusname, "", ZO_TOOLTIP_DEFAULT_COLOR:UnpackRGB())--name color
		InformationTooltip:AddLine(mundustype, "", ZO_TOOLTIP_DEFAULT_COLOR:UnpackRGB())--type color
	end,
	tooltip = InformationTooltip,
}

--Handles icon placement on maps for Mundus Stones
local function GetZoneAndSubzone()
	local textureName = GetMapTileTexture()

	textureName = string.lower(textureName)
--	d(textureName)
	local _,_,_,zone,subzone = string.find(textureName, "(maps/)([%w%-]+)/([%w%-]+_%w+)")
	
	return zone, subzone
end

function MunMap.pinCreator_Mundus(pinManager)
    if not MunMapSettings.showMundusStones then return end
	local zone, subzone = GetZoneAndSubzone()
	if MunMap.MundusMapData[zone] == nil or MunMap.MundusMapData[zone][subzone] == nil then return end
	local Munduss = MunMap.MundusMapData[zone][subzone]
	if (zone == "tamriel" and MunMapSettings.showTamrielStones == false) then return end

		for _, pinData in pairs(Munduss) do
			if (MunMapSettings.showStoneType[pinData[3]]) == true then
				-- ZO_WorldMap_AddCustomPin(pinType, addCallback, nil, pinLayoutData, pinTooltipCreator)
				pinManager:CreatePin( _G["Mundus_Stone_Pin"], pinData, pinData[1], pinData[2])
			end
		end
end

-- Secret Slash Command
local function ShowLoadStatus()
	d(MundusMapDidItLoad)
end

local function OnAddOnLoaded(eventCode, addOnName)
if(addOnName == "MundusMap") then
	
	-- Load / Create our saved variable file
	MunMapSettings = ZO_SavedVars:NewAccountWide("MUNDUSMAP_DB", 1, nil, MunMapdefaults)
	
	-- Initialize Options Window
	local LAM = LibStub:GetLibrary("LibAddonMenu-1.0")
	local MundusMapMenu = LAM:CreateControlPanel("MundusMap_Settings_Page", "MundusMap")

	-- Set Data for Secret Slash Command 
	MundusMapDidItLoad = "Yes, it did load."

	MunMap.MapPins = CustomMapPins:New()
	MunMap.MapPins:CreatePinType("Mundus_Stone_Pin", MunMap.Settings, MunMap.pinTooltipCreator, MunMap.pinCreator_Mundus)
	MunMap.MapPins:RefreshPins()
	
	if (MunMapSettings.showMundusStones == false) then
		-- MunMap.MapPins:enablePins( "Mundus_Stone_Pin", disable )
	else
		-- MunMap.MapPins:CreatePinType("Mundus_Stone_Pin", MunMap.Settings, MunMap.pinTooltipCreator, MunMap.pinCreator_Mundus)
	end

	-- MundusMap On/Off
	local function GetMundusSetting()
		return MunMapSettings.showMundusStones
	end
	
	local function FlipMundusSetting()
		if (MunMapSettings.showMundusStones == true) then
			MunMapSettings.showMundusStones = false
		else
			MunMapSettings.showMundusStones = true
			MunMap.MapPins:CreatePinType("Mundus_Stone_Pin", MunMap.Settings, MunMap.pinTooltipCreator, MunMap.pinCreator_Mundus)
		end
		MunMap.MapPins:RefreshPins()
	end
	
	-- Tamriel Map
	local function GetTamrielSetting()
		return MunMapSettings.showTamrielStones
	end
	
	local function FlipTamrielSetting()
		if (MunMapSettings.showTamrielStones == true) then
			MunMapSettings.showTamrielStones = false
		else
			MunMapSettings.showTamrielStones = true
			MunMap.MapPins:CreatePinType("Mundus_Stone_Pin", MunMap.Settings, MunMap.pinTooltipCreator, MunMap.pinCreator_Mundus)
		end
		MunMap.MapPins:RefreshPins()
	end

	function MunMap.GetPinType( stoneNumber )
		return "MnMpPin" .. stoneNumber
	end
	
	function MunMap.RefreshPins( stoneNumber )
		if not stoneNumber then
			ZO_WorldMap_RefreshCustomPinsOfType()
			-- COMPASS_PINS:RefreshPins()
			return
		end
		if stoneNumber >= 1 and stoneNumber <= 13 then
			ZO_WorldMap_RefreshCustomPinsOfType( _G[ MunMap.GetPinType( stoneNumber ) ] )
			--COMPASS_PINS:RefreshPins( MunMap.GetPinType( stoneNumber ) )
		end
	end
	
	function MunMap.GetFilter( stoneNumber )
		return MunMapSettings.showStoneType[ stoneNumber ]
	end

	function MunMap.SetFilter( stoneNumber, value )
		MunMapSettings.showStoneType[ stoneNumber ] = value
		MunMap.RefreshPins( stoneNumber )
	end
	
	LAM:AddHeader(MundusMapMenu, "MundusMap_Options_Header", "Settings")
	LAM:AddCheckbox(MundusMapMenu, "MundusMap_Show_Switch", "Show Mundus Stone Locations", "Turn MundusMap |c00FF00ON|r/|cFF0000OFF|r", GetMundusSetting, FlipMundusSetting)
	LAM:AddCheckbox(MundusMapMenu, "MundusMap_Tamriel_Switch", "Show On Tamriel Map", "Show Stones on map of Tamriel", GetTamrielSetting, FlipTamrielSetting)
	
	LAM:AddHeader(MundusMapMenu, "MundusMap_TypeHeader", "Type")
	
	for stoneNumber = 1,13 do
	--d(MunMapsettings.showStoneType[ stoneNumber ])
		LAM:AddCheckbox(MundusMapMenu, "MundusMapFilter"..stoneNumber, MunMap.localization[ "filter"..stoneNumber ].."|c00CC00 ("..MunMap.localization[ "filtertooltip"..stoneNumber ]..")", nil,
		function()
			return MunMap.GetFilter( stoneNumber )
		end,
		function( value )
			MunMap.SetFilter( stoneNumber, value )
		end,
		false, nil)
	end

	LAM:AddDescription(MundusMapMenu, "MundusMap_DedicationTitle", "|cDDAA11You are deeply missed, little buddy.", "|cDD8300This addon is dedicated to my dog Raymond:")
	--LAM:AddDescription(MundusMapMenu, "MundusMap_DedicationText", "my dog", "This addon is dedicated to my dog Raymond")
	
	-- zo_callLater(function() d("How Many Times") end, 8000)

--	LAM:AddHeader(MundusMapMenu, "MundusMap_ZoneHeader", "Zone")
--	LAM:AddCheckbox(MundusMapMenu, "MundusMap_showCyrodiil", "Cyrodiil", "Show In This Zone", GetMundus, FlipMundus)
--	LAM:AddCheckbox(MundusMapMenu, "MundusMap_showZone2", "Ebonheart Pact", "Show In This Zone", GetMundus, FlipMundus)
--	LAM:AddCheckbox(MundusMapMenu, "MundusMap_showZone3", "Daggerfall Covenant", "Show In This Zone", GetMundus, FlipMundus)
--	LAM:AddCheckbox(MundusMapMenu, "MundusMap_showZone4", "Aldmeri Dominion", "Show In This Zone", GetMundus, FlipMundus)	

	SLASH_COMMANDS["/didit"] = ShowLoadStatus
	
    end
end

-- Init MundusMap
function MundusMapInit()
	EVENT_MANAGER:RegisterForEvent("MundusMap", EVENT_ADD_ON_LOADED, OnAddOnLoaded)
end